@@ -4,6 +4,7 @@ from sqlalchemy import (
     String,
     DateTime,
     ForeignKey,
+    UniqueConstraint,
 )
 from datetime import datetime
 
@@ -35,9 +36,10 @@ class CompanySECFilingModel(Base):
     extraction_method = Column(String(50), nullable=True)
     excerpt_file_id = Column(Integer, ForeignKey("files.id"), nullable=True)
     source_file_id = Column(Integer, ForeignKey("files.id"), nullable=True)
-
     updated_at = Column(
         DateTime,
         default=datetime.utcnow,
         onupdate=datetime.utcnow,
     )
+
+    __table_args__ = (UniqueConstraint('sec_accession_number', 'document_group', 'section_name'),)
