@@ -6,6 +6,7 @@ from sqlalchemy import (
     DateTime,
     ForeignKey,
     Float,
+    Boolean,
 )
 
 from ...database import Base
@@ -26,6 +27,7 @@ class ConditionNCTModel(Base):
         nullable=False,
     )
     score = Column(Float, nullable=False)
+    preferred = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
