@@ -16,7 +16,7 @@ class GNRSSResourceSchema(Schema):
     updated_at = fields.DateTime()
 
     @pre_load
-    def convert_string_to_datetime(self, in_data):
+    def convert_string_to_datetime(self, in_data, **kwargs):
         date_fields = ['article_date']
 
         in_data = pre_load_date_fields(
