@@ -15,7 +15,7 @@ class InvestorModel(Base):
     __tablename__ = "investors"
 
     id = Column(Integer, primary_key=True)
-    name = Column(String(256), nullable=False)
+    name = Column(String(191), nullable=False, index=True)
     aliases = Column(Text, nullable=True)
     website = Column(String(256), nullable=True)
     type = Column(String(50), nullable=True)
