@@ -23,7 +23,7 @@ class NCTChangeResourceSchema(Schema):
     updated_at = fields.DateTime(dump_only=True)
 
     @pre_load
-    def convert_string_to_datetime(self, in_data):
+    def convert_string_to_datetime(self, in_data, **kwargs):
         date_fields = ['date']
 
         in_data = pre_load_date_fields(
