@@ -32,7 +32,7 @@ class NCTStudyResourceSchema(Schema):
     updated_at = fields.DateTime(dump_only=True)
 
     @pre_load
-    def convert_string_to_datetime(self, in_data):
+    def convert_string_to_datetime(self, in_data, **kwargs):
         date_fields = ['study_start_date', 'last_update_submitted_qc_date', 'study_first_posted_date', 'primary_completion_date']
 
         in_data = pre_load_date_fields(
