@@ -17,9 +17,13 @@ class PatentApplicationModel(Base):
     id = Column(Integer, primary_key=True)
     application_number = Column(String(128), nullable=False)
     jurisdiction = Column(String(128), nullable=False)
+    app_grp_art_number = Column(Integer, nullable=True)
     abstract_text = Column(Text)
     filed_date = Column(DateTime)
     inventors = Column(Text)
+    applicant = Column(Text)
+    app_class = Column(String(20))
+    app_sub_class = Column(String(20))
     title = Column(String(500))
 
     updated_at = Column(
