@@ -5,6 +5,8 @@ from sqlalchemy import (
     Integer,
     DateTime,
     ForeignKey,
+    Boolean,
+    Float,
 )
 
 from ...database import Base
@@ -24,6 +26,12 @@ class PubmedInterventionModel(Base):
         ForeignKey('interventions.id'),
         nullable=False,
     )
+    score = Column(
+        Float,
+        nullable=False,
+    )
+    preferred = Column(Boolean, nullable=True)
+    data_readout = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
